package com.jiuqi.grid;

import com.jiuqi.util.Stream;
import com.jiuqi.util.StreamException;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/* loaded from: com_jiuqi_grid.jar:com/jiuqi/grid/PropList.class */
public class PropList implements Serializable {
    private int bufSize;
    private List list = new ArrayList();
    private Map finder = new HashMap();
    private Key tmpKey = new Key();

    public PropList(int bufferSize) {
        this.bufSize = bufferSize;
    }

    public byte[] get(int index) {
        return (byte[]) this.list.get(index);
    }

    public void set(int index, byte[] value) {
        this.finder.remove(this.tmpKey.setProperty((byte[]) this.list.get(index)));
        byte[] b = (byte[]) this.list.get(index);
        System.arraycopy(value, 0, b, 0, this.bufSize);
        this.finder.put(new Key(b), new Integer(index));
    }

    public int indexOf(byte[] propData) {
        Integer index = (Integer) this.finder.get(this.tmpKey.setProperty(propData));
        if (index == null) {
            return -1;
        }
        return index.intValue();
    }

    public int count() {
        return this.list.size();
    }

    public void setCount(int value) {
        for (int i = this.list.size(); i < value; i++) {
            this.list.add(new byte[this.bufSize]);
        }
        for (int i2 = this.list.size() - 1; i2 >= value; i2--) {
            this.list.remove(i2);
        }
    }

    public int add(byte[] propData) {
        byte[] b = new byte[this.bufSize];
        System.arraycopy(propData, 0, b, 0, this.bufSize);
        int index = this.list.size();
        this.list.add(b);
        this.finder.put(new Key(b), new Integer(index));
        return index;
    }

    private void rebuild() {
        this.finder.clear();
        for (int i = 0; i < this.list.size(); i++) {
            this.finder.put(new Key((byte[]) this.list.get(i)), new Integer(i));
        }
    }

    public void loadFromStream(Stream stream, int size) throws StreamException {
        this.list.clear();
        for (int i = 0; i < size / this.bufSize; i++) {
            byte[] b = new byte[this.bufSize];
            stream.readBuffer(b, 0, this.bufSize);
            this.list.add(b);
        }
        rebuild();
    }

    public void loadFromStreamEx(Stream stream, int bufStart, int bufLen) throws StreamException {
        int count = (int) (stream.getSize() / bufLen);
        setCount(count);
        stream.setPosition(0L);
        for (int i = 0; i < count; i++) {
            byte[] buf = (byte[]) this.list.get(i);
            stream.readBuffer(buf, bufStart, bufLen);
        }
        rebuild();
    }

    public void saveToStream(Stream stream) throws StreamException {
        for (int i = 0; i < this.list.size(); i++) {
            byte[] b = (byte[]) this.list.get(i);
            stream.writeBuffer(b, 0, this.bufSize);
        }
    }

    public void saveToStreamEx(Stream stream, int bufStart, int bufLen) throws StreamException {
        for (int i = 0; i < this.list.size(); i++) {
            byte[] buf = (byte[]) this.list.get(i);
            stream.writeBuffer(buf, bufStart, bufLen);
        }
    }

    public void remove(int index) {
        this.list.remove(index);
        rebuild();
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: com_jiuqi_grid.jar:com/jiuqi/grid/PropList$Key.class */
    public static final class Key {
        private byte[] property;
        private int hash;

        public Key() {
        }

        public Key(byte[] property) {
            setProperty(property);
        }

        public Key setProperty(byte[] property) {
            this.property = property;
            if (property == null) {
                this.hash = 0;
            } else {
                this.hash = 1;
                for (byte b : property) {
                    this.hash = (31 * this.hash) + b;
                }
            }
            return this;
        }

        public int hashCode() {
            return this.hash;
        }

        public boolean equals(Object obj) {
            if (hashCode() != obj.hashCode() || !(obj instanceof Key)) {
                return false;
            }
            Key another = (Key) obj;
            if (this.property == null) {
                return another.property == null;
            }
            for (int i = 0; i < this.property.length; i++) {
                if (this.property[i] != another.property[i]) {
                    return false;
                }
            }
            return true;
        }

        public String toString() {
            StringBuffer s = new StringBuffer();
            s.append(this.property).append('(').append(this.hash).append(')');
            return s.toString();
        }
    }
}
